# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler. DO NOT EDIT!
# See https://github.com/eolymp/contracts/tree/main/cmd/protoc-gen-python-esdk for more details.
"""Generated protocol buffer code."""

import urllib.parse
from google.protobuf import symbol_database as _symbol_database

_sym_db = _symbol_database.Default()


class BillingServiceClient:
    def __init__(self, transport, url="https://api.eolymp.com"):
        self.transport = transport
        self.url = url

    def DescribeBillingInformation(self, request, **kwargs):
        path = "/billing/info"

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.universe.DescribeBillingInformationOutput"),
            **kwargs,
        )

    def UpdateBillingInformation(self, request, **kwargs):
        path = "/billing/info"

        return self.transport.request(
            method="PUT",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.universe.UpdateBillingInformationOutput"),
            **kwargs,
        )

    def DescribeSubscription(self, request, **kwargs):
        path = "/billing/subscription"

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.universe.DescribeSubscriptionOutput"),
            **kwargs,
        )

    def CreateSubscription(self, request, **kwargs):
        path = "/billing/subscription"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.universe.CreateSubscriptionOutput"),
            **kwargs,
        )

    def UpdateSubscription(self, request, **kwargs):
        path = "/billing/subscription"

        return self.transport.request(
            method="PUT",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.universe.UpdateSubscriptionOutput"),
            **kwargs,
        )

    def CancelSubscription(self, request, **kwargs):
        path = "/billing/subscription"

        return self.transport.request(
            method="DELETE",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.universe.CancelSubscriptionOutput"),
            **kwargs,
        )

    def StartSubscriptionTrial(self, request, **kwargs):
        path = "/billing/trial/start"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.universe.StartSubscriptionTrialOutput"),
            **kwargs,
        )

    def EndSubscriptionTrial(self, request, **kwargs):
        path = "/billing/trial/end"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.universe.EndSubscriptionTrialOutput"),
            **kwargs,
        )

    def SimulateSubscription(self, request, **kwargs):
        path = "/billing/subscription/simulate"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.universe.SimulateSubscriptionOutput"),
            **kwargs,
        )

    def CreatePortalLink(self, request, **kwargs):
        path = "/billing/portal-link"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.universe.CreatePortalLinkOutput"),
            **kwargs,
        )

    def UpcomingInvoice(self, request, **kwargs):
        path = "/billing/upcoming"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.universe.UpcomingInvoiceOutput"),
            **kwargs,
        )

    def DescribeInvoice(self, request, **kwargs):
        path = "/billing/invoice/"+urllib.parse.quote(request.invoice_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.invoice_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.universe.DescribeInvoiceOutput"),
            **kwargs,
        )

    def PayInvoice(self, request, **kwargs):
        path = "/billing/invoice/"+urllib.parse.quote(request.invoice_id)+"/pay"

        # Cleanup URL parameters to avoid any ambiguity
        request.invoice_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.universe.PayInvoiceOutput"),
            **kwargs,
        )

    def ListInvoices(self, request, **kwargs):
        path = "/billing/invoices"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.universe.ListInvoicesOutput"),
            **kwargs,
        )

    def ListAvailablePlans(self, request, **kwargs):
        path = "/billing/plans"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.universe.ListAvailablePlansOutput"),
            **kwargs,
        )




# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/course/material.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/course/material.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.ecm import content_pb2 as eolymp_dot_ecm_dot_content__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x65olymp/course/material.proto\x12\reolymp.course\x1a\x18\x65olymp/ecm/content.proto\"\xe2\x05\n\x08Material\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\r\n\x05\x64raft\x18\x03 \x01(\x08\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x11\n\timage_url\x18\x05 \x01(\t\x12\x11\n\tmodule_id\x18\x06 \x01(\t\x12\r\n\x05index\x18\x0b \x01(\r\x12\r\n\x05\x64\x65pth\x18\x0c \x01(\r\x12\x30\n\x07grading\x18\x1e \x01(\x0b\x32\x1f.eolymp.course.Material.Grading\x12\x34\n\x08\x64ocument\x18\x64 \x01(\x0b\x32 .eolymp.course.Material.DocumentH\x00\x12,\n\x04task\x18\x65 \x01(\x0b\x32\x1c.eolymp.course.Material.TaskH\x00\x12\x12\n\npercentage\x18\x14 \x01(\x02\x12\r\n\x05grade\x18\x15 \x01(\r\x12\x32\n\x08progress\x18\x16 \x01(\x0b\x32 .eolymp.course.Material.Progress\x1a\x30\n\x08\x44ocument\x12$\n\x07\x63ontent\x18\x01 \x01(\x0b\x32\x13.eolymp.ecm.Content\x1a\x1a\n\x04Task\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x1a,\n\x07Grading\x12\x11\n\tmax_score\x18\x01 \x01(\r\x12\x0e\n\x06weight\x18\x02 \x01(\x02\x1ao\n\x08Progress\x12\x12\n\npercentage\x18\x14 \x01(\x02\x12\r\n\x05grade\x18\x15 \x01(\r\x12\x17\n\x0fgrade_automatic\x18\x16 \x01(\r\x12\x16\n\x0egrade_override\x18\x17 \x01(\r\x12\x0f\n\x07\x65xcused\x18\x18 \x01(\x08\"w\n\x05\x45xtra\x12\x11\n\rUNKNOWN_EXTRA\x10\x00\x12\x0b\n\x07\x43ONTENT\x10\x01\x12\x11\n\rCONTENT_VALUE\x10\x02\x12\x12\n\x0e\x43ONTENT_RENDER\x10\x03\x12\x0e\n\nPERCENTAGE\x10\x04\x12\t\n\x05GRADE\x10\x05\x12\x0c\n\x08PROGRESS\x10\x06\x42\t\n\x07\x63ontentB/Z-github.com/eolymp/go-sdk/eolymp/course;courseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.course.material_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/course;course'
  _globals['_MATERIAL']._serialized_start=74
  _globals['_MATERIAL']._serialized_end=812
  _globals['_MATERIAL_DOCUMENT']._serialized_start=445
  _globals['_MATERIAL_DOCUMENT']._serialized_end=493
  _globals['_MATERIAL_TASK']._serialized_start=495
  _globals['_MATERIAL_TASK']._serialized_end=521
  _globals['_MATERIAL_GRADING']._serialized_start=523
  _globals['_MATERIAL_GRADING']._serialized_end=567
  _globals['_MATERIAL_PROGRESS']._serialized_start=569
  _globals['_MATERIAL_PROGRESS']._serialized_end=680
  _globals['_MATERIAL_EXTRA']._serialized_start=682
  _globals['_MATERIAL_EXTRA']._serialized_end=801
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor_pb2 as _descriptor_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor
HTTP_FIELD_NUMBER: _ClassVar[int]
http: _descriptor.FieldDescriptor

class Http(_message.Message):
    __slots__ = ("rules", "fully_decode_reserved_expansion")
    RULES_FIELD_NUMBER: _ClassVar[int]
    FULLY_DECODE_RESERVED_EXPANSION_FIELD_NUMBER: _ClassVar[int]
    rules: _containers.RepeatedCompositeFieldContainer[HttpRule]
    fully_decode_reserved_expansion: bool
    def __init__(self, rules: _Optional[_Iterable[_Union[HttpRule, _Mapping]]] = ..., fully_decode_reserved_expansion: bool = ...) -> None: ...

class HttpRule(_message.Message):
    __slots__ = ("selector", "get", "put", "post", "delete", "patch", "custom", "body", "response_body", "additional_bindings")
    SELECTOR_FIELD_NUMBER: _ClassVar[int]
    GET_FIELD_NUMBER: _ClassVar[int]
    PUT_FIELD_NUMBER: _ClassVar[int]
    POST_FIELD_NUMBER: _ClassVar[int]
    DELETE_FIELD_NUMBER: _ClassVar[int]
    PATCH_FIELD_NUMBER: _ClassVar[int]
    CUSTOM_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_BODY_FIELD_NUMBER: _ClassVar[int]
    ADDITIONAL_BINDINGS_FIELD_NUMBER: _ClassVar[int]
    selector: str
    get: str
    put: str
    post: str
    delete: str
    patch: str
    custom: CustomHttpPattern
    body: str
    response_body: str
    additional_bindings: _containers.RepeatedCompositeFieldContainer[HttpRule]
    def __init__(self, selector: _Optional[str] = ..., get: _Optional[str] = ..., put: _Optional[str] = ..., post: _Optional[str] = ..., delete: _Optional[str] = ..., patch: _Optional[str] = ..., custom: _Optional[_Union[CustomHttpPattern, _Mapping]] = ..., body: _Optional[str] = ..., response_body: _Optional[str] = ..., additional_bindings: _Optional[_Iterable[_Union[HttpRule, _Mapping]]] = ...) -> None: ...

class CustomHttpPattern(_message.Message):
    __slots__ = ("kind", "path")
    KIND_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    kind: str
    path: str
    def __init__(self, kind: _Optional[str] = ..., path: _Optional[str] = ...) -> None: ...



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Version(_message.Message):
    __slots__ = ("id", "number", "created_at", "created_by", "summary", "changes", "cursor")
    class Operation(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_OPERATION: _ClassVar[Version.Operation]
        ADD: _ClassVar[Version.Operation]
        UPDATE: _ClassVar[Version.Operation]
        DELETE: _ClassVar[Version.Operation]
    UNKNOWN_OPERATION: Version.Operation
    ADD: Version.Operation
    UPDATE: Version.Operation
    DELETE: Version.Operation
    class Change(_message.Message):
        __slots__ = ("op", "path")
        OP_FIELD_NUMBER: _ClassVar[int]
        PATH_FIELD_NUMBER: _ClassVar[int]
        op: Version.Operation
        path: str
        def __init__(self, op: _Optional[_Union[Version.Operation, str]] = ..., path: _Optional[str] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    NUMBER_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    CREATED_BY_FIELD_NUMBER: _ClassVar[int]
    SUMMARY_FIELD_NUMBER: _ClassVar[int]
    CHANGES_FIELD_NUMBER: _ClassVar[int]
    CURSOR_FIELD_NUMBER: _ClassVar[int]
    id: str
    number: int
    created_at: _timestamp_pb2.Timestamp
    created_by: str
    summary: str
    changes: _containers.RepeatedCompositeFieldContainer[Version.Change]
    cursor: str
    def __init__(self, id: _Optional[str] = ..., number: _Optional[int] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., created_by: _Optional[str] = ..., summary: _Optional[str] = ..., changes: _Optional[_Iterable[_Union[Version.Change, _Mapping]]] = ..., cursor: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/community/linked_account_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/community/linked_account_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.community import linked_account_pb2 as eolymp_dot_community_dot_linked__account__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-eolymp/community/linked_account_service.proto\x12\x10\x65olymp.community\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a%eolymp/community/linked_account.proto\x1a!eolymp/wellknown/expression.proto\"O\n\x19RequestLinkedAccountInput\x12\x32\n\x04type\x18\x01 \x01(\x0e\x32$.eolymp.community.LinkedAccount.Type\"2\n\x1aRequestLinkedAccountOutput\x12\x14\n\x0credirect_uri\x18\x01 \x01(\t\"7\n\x18\x43reateLinkedAccountInput\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\r\n\x05state\x18\x02 \x01(\t\",\n\x19\x43reateLinkedAccountOutput\x12\x0f\n\x07link_id\x18\x01 \x01(\t\"+\n\x18\x44\x65leteLinkedAccountInput\x12\x0f\n\x07link_id\x18\x01 \x01(\t\"\x1b\n\x19\x44\x65leteLinkedAccountOutput\"-\n\x1a\x44\x65scribeLinkedAccountInput\x12\x0f\n\x07link_id\x18\x01 \x01(\t\"L\n\x1b\x44\x65scribeLinkedAccountOutput\x12-\n\x04link\x18\x01 \x01(\x0b\x32\x1f.eolymp.community.LinkedAccount\"\xe0\x01\n\x17ListLinkedAccountsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x41\n\x07\x66ilters\x18( \x01(\x0b\x32\x30.eolymp.community.ListLinkedAccountsInput.Filter\x1a\x64\n\x06\x46ilter\x12*\n\x02id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12.\n\x04type\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"Y\n\x18ListLinkedAccountsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12.\n\x05items\x18\x02 \x03(\x0b\x32\x1f.eolymp.community.LinkedAccount2\xba\x06\n\x14LinkedAccountService\x12\xa2\x01\n\x14RequestLinkedAccount\x12+.eolymp.community.RequestLinkedAccountInput\x1a,.eolymp.community.RequestLinkedAccountOutput\"/\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x1a\"\x18/linked-accounts:request\x12\x97\x01\n\x13\x43reateLinkedAccount\x12*.eolymp.community.CreateLinkedAccountInput\x1a+.eolymp.community.CreateLinkedAccountOutput\"\'\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x12\"\x10/linked-accounts\x12\xa1\x01\n\x13\x44\x65leteLinkedAccount\x12*.eolymp.community.DeleteLinkedAccountInput\x1a+.eolymp.community.DeleteLinkedAccountOutput\"1\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x1c*\x1a/linked-accounts/{link_id}\x12\xa7\x01\n\x15\x44\x65scribeLinkedAccount\x12,.eolymp.community.DescribeLinkedAccountInput\x1a-.eolymp.community.DescribeLinkedAccountOutput\"1\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x1c\x12\x1a/linked-accounts/{link_id}\x12\x94\x01\n\x12ListLinkedAccounts\x12).eolymp.community.ListLinkedAccountsInput\x1a*.eolymp.community.ListLinkedAccountsOutput\"\'\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x12\x12\x10/linked-accountsB5Z3github.com/eolymp/go-sdk/eolymp/community;communityb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.community.linked_account_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/community;community'
  _globals['_LINKEDACCOUNTSERVICE'].methods_by_name['RequestLinkedAccount']._loaded_options = None
  _globals['_LINKEDACCOUNTSERVICE'].methods_by_name['RequestLinkedAccount']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\032\"\030/linked-accounts:request'
  _globals['_LINKEDACCOUNTSERVICE'].methods_by_name['CreateLinkedAccount']._loaded_options = None
  _globals['_LINKEDACCOUNTSERVICE'].methods_by_name['CreateLinkedAccount']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\022\"\020/linked-accounts'
  _globals['_LINKEDACCOUNTSERVICE'].methods_by_name['DeleteLinkedAccount']._loaded_options = None
  _globals['_LINKEDACCOUNTSERVICE'].methods_by_name['DeleteLinkedAccount']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\034*\032/linked-accounts/{link_id}'
  _globals['_LINKEDACCOUNTSERVICE'].methods_by_name['DescribeLinkedAccount']._loaded_options = None
  _globals['_LINKEDACCOUNTSERVICE'].methods_by_name['DescribeLinkedAccount']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\034\022\032/linked-accounts/{link_id}'
  _globals['_LINKEDACCOUNTSERVICE'].methods_by_name['ListLinkedAccounts']._loaded_options = None
  _globals['_LINKEDACCOUNTSERVICE'].methods_by_name['ListLinkedAccounts']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\022\022\020/linked-accounts'
  _globals['_REQUESTLINKEDACCOUNTINPUT']._serialized_start=208
  _globals['_REQUESTLINKEDACCOUNTINPUT']._serialized_end=287
  _globals['_REQUESTLINKEDACCOUNTOUTPUT']._serialized_start=289
  _globals['_REQUESTLINKEDACCOUNTOUTPUT']._serialized_end=339
  _globals['_CREATELINKEDACCOUNTINPUT']._serialized_start=341
  _globals['_CREATELINKEDACCOUNTINPUT']._serialized_end=396
  _globals['_CREATELINKEDACCOUNTOUTPUT']._serialized_start=398
  _globals['_CREATELINKEDACCOUNTOUTPUT']._serialized_end=442
  _globals['_DELETELINKEDACCOUNTINPUT']._serialized_start=444
  _globals['_DELETELINKEDACCOUNTINPUT']._serialized_end=487
  _globals['_DELETELINKEDACCOUNTOUTPUT']._serialized_start=489
  _globals['_DELETELINKEDACCOUNTOUTPUT']._serialized_end=516
  _globals['_DESCRIBELINKEDACCOUNTINPUT']._serialized_start=518
  _globals['_DESCRIBELINKEDACCOUNTINPUT']._serialized_end=563
  _globals['_DESCRIBELINKEDACCOUNTOUTPUT']._serialized_start=565
  _globals['_DESCRIBELINKEDACCOUNTOUTPUT']._serialized_end=641
  _globals['_LISTLINKEDACCOUNTSINPUT']._serialized_start=644
  _globals['_LISTLINKEDACCOUNTSINPUT']._serialized_end=868
  _globals['_LISTLINKEDACCOUNTSINPUT_FILTER']._serialized_start=768
  _globals['_LISTLINKEDACCOUNTSINPUT_FILTER']._serialized_end=868
  _globals['_LISTLINKEDACCOUNTSOUTPUT']._serialized_start=870
  _globals['_LISTLINKEDACCOUNTSOUTPUT']._serialized_end=959
  _globals['_LINKEDACCOUNTSERVICE']._serialized_start=962
  _globals['_LINKEDACCOUNTSERVICE']._serialized_end=1788
# @@protoc_insertion_point(module_scope)



from eolymp.ecm import content_pb2 as _content_pb2
from eolymp.universe import quota_pb2 as _quota_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Plan(_message.Message):
    __slots__ = ("id", "name", "description", "quota", "labels", "requires_approval", "min_seats", "max_seats", "variants")
    class Extra(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        NO_EXTRA: _ClassVar[Plan.Extra]
        DESCRIPTION_RENDER: _ClassVar[Plan.Extra]
        DESCRIPTION_VALUE: _ClassVar[Plan.Extra]
    NO_EXTRA: Plan.Extra
    DESCRIPTION_RENDER: Plan.Extra
    DESCRIPTION_VALUE: Plan.Extra
    class Recurrence(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_RECURRENCE: _ClassVar[Plan.Recurrence]
        ONETIME: _ClassVar[Plan.Recurrence]
        MONTHLY: _ClassVar[Plan.Recurrence]
        YEARLY: _ClassVar[Plan.Recurrence]
    UNKNOWN_RECURRENCE: Plan.Recurrence
    ONETIME: Plan.Recurrence
    MONTHLY: Plan.Recurrence
    YEARLY: Plan.Recurrence
    class Variant(_message.Message):
        __slots__ = ("id", "recurrence", "currency", "unit_amount")
        ID_FIELD_NUMBER: _ClassVar[int]
        RECURRENCE_FIELD_NUMBER: _ClassVar[int]
        CURRENCY_FIELD_NUMBER: _ClassVar[int]
        UNIT_AMOUNT_FIELD_NUMBER: _ClassVar[int]
        id: str
        recurrence: Plan.Recurrence
        currency: str
        unit_amount: int
        def __init__(self, id: _Optional[str] = ..., recurrence: _Optional[_Union[Plan.Recurrence, str]] = ..., currency: _Optional[str] = ..., unit_amount: _Optional[int] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    QUOTA_FIELD_NUMBER: _ClassVar[int]
    LABELS_FIELD_NUMBER: _ClassVar[int]
    REQUIRES_APPROVAL_FIELD_NUMBER: _ClassVar[int]
    MIN_SEATS_FIELD_NUMBER: _ClassVar[int]
    MAX_SEATS_FIELD_NUMBER: _ClassVar[int]
    VARIANTS_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    description: _content_pb2.Content
    quota: _quota_pb2.Quota
    labels: _containers.RepeatedScalarFieldContainer[str]
    requires_approval: bool
    min_seats: int
    max_seats: int
    variants: _containers.RepeatedCompositeFieldContainer[Plan.Variant]
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[_Union[_content_pb2.Content, _Mapping]] = ..., quota: _Optional[_Union[_quota_pb2.Quota, _Mapping]] = ..., labels: _Optional[_Iterable[str]] = ..., requires_approval: bool = ..., min_seats: _Optional[int] = ..., max_seats: _Optional[int] = ..., variants: _Optional[_Iterable[_Union[Plan.Variant, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/universe/plan_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/universe/plan_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.universe import plan_pb2 as eolymp_dot_universe_dot_plan__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"eolymp/universe/plan_service.proto\x12\x0f\x65olymp.universe\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1a\x65olymp/universe/plan.proto\"s\n\x11\x44\x65scribePlanInput\x12\x0f\n\x07plan_id\x18\x01 \x01(\t\x12\x0e\n\x06locale\x18\x65 \x01(\t\x12\x10\n\x08\x63urrency\x18\x66 \x01(\t\x12+\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1b.eolymp.universe.Plan.Extra\"9\n\x12\x44\x65scribePlanOutput\x12#\n\x04plan\x18\x01 \x01(\x0b\x32\x15.eolymp.universe.Plan\"}\n\x0eListPlansInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x0e\n\x06locale\x18\x65 \x01(\t\x12\x10\n\x08\x63urrency\x18\x66 \x01(\t\x12+\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1b.eolymp.universe.Plan.Extra\"F\n\x0fListPlansOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12$\n\x05items\x18\x02 \x03(\x0b\x32\x15.eolymp.universe.Plan2\xff\x01\n\x0bPlanService\x12\x80\x01\n\x0c\x44\x65scribePlan\x12\".eolymp.universe.DescribePlanInput\x1a#.eolymp.universe.DescribePlanOutput\"\'\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x12\x12\x10/plans/{plan_id}\x12m\n\tListPlans\x12\x1f.eolymp.universe.ListPlansInput\x1a .eolymp.universe.ListPlansOutput\"\x1d\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x08\x12\x06/plansB3Z1github.com/eolymp/go-sdk/eolymp/universe;universeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.universe.plan_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/universe;universe'
  _globals['_PLANSERVICE'].methods_by_name['DescribePlan']._loaded_options = None
  _globals['_PLANSERVICE'].methods_by_name['DescribePlan']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\022\022\020/plans/{plan_id}'
  _globals['_PLANSERVICE'].methods_by_name['ListPlans']._loaded_options = None
  _globals['_PLANSERVICE'].methods_by_name['ListPlans']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\010\022\006/plans'
  _globals['_DESCRIBEPLANINPUT']._serialized_start=150
  _globals['_DESCRIBEPLANINPUT']._serialized_end=265
  _globals['_DESCRIBEPLANOUTPUT']._serialized_start=267
  _globals['_DESCRIBEPLANOUTPUT']._serialized_end=324
  _globals['_LISTPLANSINPUT']._serialized_start=326
  _globals['_LISTPLANSINPUT']._serialized_end=451
  _globals['_LISTPLANSOUTPUT']._serialized_start=453
  _globals['_LISTPLANSOUTPUT']._serialized_end=523
  _globals['_PLANSERVICE']._serialized_start=526
  _globals['_PLANSERVICE']._serialized_end=781
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler. DO NOT EDIT!
# See https://github.com/eolymp/contracts/tree/main/cmd/protoc-gen-python-esdk for more details.
"""Generated protocol buffer code."""

import urllib.parse
from google.protobuf import symbol_database as _symbol_database

_sym_db = _symbol_database.Default()


class EditorialServiceClient:
    def __init__(self, transport, url="https://api.eolymp.com"):
        self.transport = transport
        self.url = url

    def CreateEditorial(self, request, **kwargs):
        path = "/editorials"

        return self.transport.request(
            method="PUT",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.CreateEditorialOutput"),
            **kwargs,
        )

    def UpdateEditorial(self, request, **kwargs):
        path = "/editorials/"+urllib.parse.quote(request.editorial_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.editorial_id = ""

        return self.transport.request(
            method="PUT",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.UpdateEditorialOutput"),
            **kwargs,
        )

    def DeleteEditorial(self, request, **kwargs):
        path = "/editorials/"+urllib.parse.quote(request.editorial_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.editorial_id = ""

        return self.transport.request(
            method="DELETE",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.DeleteEditorialOutput"),
            **kwargs,
        )

    def DescribeEditorial(self, request, **kwargs):
        path = "/editorials/"+urllib.parse.quote(request.editorial_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.editorial_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.DescribeEditorialOutput"),
            **kwargs,
        )

    def LookupEditorial(self, request, **kwargs):
        path = "/editorial"

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.LookupEditorialOutput"),
            **kwargs,
        )

    def PreviewEditorial(self, request, **kwargs):
        path = "/editorial/preview"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.PreviewEditorialOutput"),
            **kwargs,
        )

    def ListEditorials(self, request, **kwargs):
        path = "/editorials"

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.ListEditorialsOutput"),
            **kwargs,
        )

    def TranslateEditorials(self, request, **kwargs):
        path = "/editorials:translate"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.TranslateEditorialsOutput"),
            **kwargs,
        )




# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/judge/ticket_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/judge/ticket_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.ecm import content_pb2 as eolymp_dot_ecm_dot_content__pb2
from eolymp.judge import ticket_pb2 as eolymp_dot_judge_dot_ticket__pb2
from eolymp.judge import ticket_reply_pb2 as eolymp_dot_judge_dot_ticket__reply__pb2
from eolymp.wellknown import direction_pb2 as eolymp_dot_wellknown_dot_direction__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!eolymp/judge/ticket_service.proto\x12\x0c\x65olymp.judge\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x18\x65olymp/ecm/content.proto\x1a\x19\x65olymp/judge/ticket.proto\x1a\x1f\x65olymp/judge/ticket_reply.proto\x1a eolymp/wellknown/direction.proto\x1a!eolymp/wellknown/expression.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"n\n\x12TicketChangedEvent\x12\r\n\x05scope\x18\n \x01(\t\x12$\n\x06\x62\x65\x66ore\x18\x01 \x01(\x0b\x32\x14.eolymp.judge.Ticket\x12#\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\x14.eolymp.judge.Ticket\"o\n\x11ReplyChangedEvent\x12\x11\n\tticket_id\x18\x01 \x01(\t\x12#\n\x06\x62\x65\x66ore\x18\x02 \x01(\x0b\x32\x13.eolymp.judge.Reply\x12\"\n\x05\x61\x66ter\x18\x03 \x01(\x0b\x32\x13.eolymp.judge.Reply\"s\n\x11\x43reateTicketInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x0f\n\x07subject\x18\x02 \x01(\t\x12$\n\x07message\x18\x04 \x01(\x0b\x32\x13.eolymp.ecm.Content\x12\x13\n\x0braw_message\x18\x03 \x01(\t\"\'\n\x12\x43reateTicketOutput\x12\x11\n\tticket_id\x18\x01 \x01(\t\"\xad\x01\n\x11UpdateTicketInput\x12\x34\n\x05patch\x18\x03 \x03(\x0e\x32%.eolymp.judge.UpdateTicketInput.Patch\x12\x11\n\tticket_id\x18\x01 \x01(\t\x12$\n\x06ticket\x18\x02 \x01(\x0b\x32\x14.eolymp.judge.Ticket\")\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\n\n\x06STATUS\x10\x01\x12\x0b\n\x07SUBJECT\x10\x02\"\x14\n\x12UpdateTicketOutput\"g\n\x0fReadTicketInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x11\n\tticket_id\x18\x02 \x01(\t\x12-\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x12\n\x10ReadTicketOutput\":\n\x11\x44\x65leteTicketInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x11\n\tticket_id\x18\x02 \x01(\t\"\x14\n\x12\x44\x65leteTicketOutput\"h\n\x13\x44\x65scribeTicketInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x11\n\tticket_id\x18\x02 \x01(\t\x12*\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1a.eolymp.judge.Ticket.Extra\"<\n\x14\x44\x65scribeTicketOutput\x12$\n\x06ticket\x18\x01 \x01(\x0b\x32\x14.eolymp.judge.Ticket\"\xc7\x05\n\x10ListTicketsInput\x12\r\n\x05\x61\x66ter\x18\x0c \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x36\n\x07\x66ilters\x18( \x01(\x0b\x32%.eolymp.judge.ListTicketsInput.Filter\x12\x31\n\x04sort\x18\x32 \x01(\x0e\x32#.eolymp.judge.ListTicketsInput.Sort\x12*\n\x05order\x18\x33 \x01(\x0e\x32\x1b.eolymp.wellknown.Direction\x12*\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1a.eolymp.judge.Ticket.Extra\x1a\x9a\x03\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x32\n\ncontest_id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x36\n\x0eparticipant_id\x18\x03 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x31\n\tmember_id\x18\x08 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x31\n\x07is_read\x18\x05 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12\x31\n\x07is_open\x18\x06 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12-\n\x03own\x18\x07 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12\x30\n\x06status\x18\t \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"&\n\x04Sort\x12\x0e\n\nCREATED_AT\x10\x00\x12\x0e\n\nUPDATED_AT\x10\x01\"a\n\x11ListTicketsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12#\n\x05items\x18\x02 \x03(\x0b\x32\x14.eolymp.judge.Ticket\x12\x18\n\x10next_page_cursor\x18\x03 \x01(\t\"\x82\x01\n\x10ReplyTicketInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\x12$\n\x07message\x18\n \x01(\x0b\x32\x13.eolymp.ecm.Content\x12\x35\n\x10\x63hange_status_to\x18\x14 \x01(\x0e\x32\x1b.eolymp.judge.Ticket.Status\"%\n\x11ReplyTicketOutput\x12\x10\n\x08reply_id\x18\x01 \x01(\t\"Q\n\x10WatchTicketInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\x12*\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1a.eolymp.judge.Ticket.Extra\"9\n\x11WatchTicketOutput\x12$\n\x06ticket\x18\x01 \x01(\x0b\x32\x14.eolymp.judge.Ticket\"v\n\x11WatchTicketsInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x11\n\tmember_id\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\x12*\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1a.eolymp.judge.Ticket.Extra\"\xb4\x01\n\x12WatchTicketsOutput\x12\x35\n\x05\x65vent\x18\x01 \x01(\x0e\x32&.eolymp.judge.WatchTicketsOutput.Event\x12$\n\x06ticket\x18\x02 \x01(\x0b\x32\x14.eolymp.judge.Ticket\"A\n\x05\x45vent\x12\x11\n\rUNKNOWN_EVENT\x10\x00\x12\x0b\n\x07\x43REATED\x10\x01\x12\x0b\n\x07UPDATED\x10\x02\x12\x0b\n\x07\x44\x45LETED\x10\x03\"@\n\x17WatchTicketSummaryInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x11\n\tmember_id\x18\x02 \x01(\t\"J\n\x18WatchTicketSummaryOutput\x12\x14\n\x0cunread_count\x18\x03 \x01(\r\x12\x18\n\x10unresolved_count\x18\x04 \x01(\r\"n\n\x10ListRepliesInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12)\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x19.eolymp.judge.Reply.Extra\"F\n\x11ListRepliesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\"\n\x05items\x18\x02 \x03(\x0b\x32\x13.eolymp.judge.Reply\"d\n\x12\x44\x65scribeReplyInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\x12\x10\n\x08reply_id\x18\x02 \x01(\t\x12)\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x19.eolymp.judge.Reply.Extra\"9\n\x13\x44\x65scribeReplyOutput\x12\"\n\x05reply\x18\x01 \x01(\x0b\x32\x13.eolymp.judge.Reply\"7\n\x10\x44\x65leteReplyInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\x12\x10\n\x08reply_id\x18\x02 \x01(\t\"\x13\n\x11\x44\x65leteReplyOutput\"]\n\x10UpdateReplyInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\x12\x10\n\x08reply_id\x18\x02 \x01(\t\x12$\n\x07message\x18\x03 \x01(\x0b\x32\x13.eolymp.ecm.Content\"\x13\n\x11UpdateReplyOutput\"a\n\x11WatchRepliesInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\x12\x0e\n\x06\x63ursor\x18\x02 \x01(\t\x12)\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x19.eolymp.judge.Reply.Extra\"\xb2\x01\n\x12WatchRepliesOutput\x12\x35\n\x05\x65vent\x18\x01 \x01(\x0e\x32&.eolymp.judge.WatchRepliesOutput.Event\x12\"\n\x05reply\x18\x02 \x01(\x0b\x32\x13.eolymp.judge.Reply\"A\n\x05\x45vent\x12\x11\n\rUNKNOWN_EVENT\x10\x00\x12\x0b\n\x07\x43REATED\x10\x01\x12\x0b\n\x07UPDATED\x10\x02\x12\x0b\n\x07\x44\x45LETED\x10\x03\x32\xc9\x11\n\rTicketService\x12\x93\x01\n\x0c\x43reateTicket\x12\x1f.eolymp.judge.CreateTicketInput\x1a .eolymp.judge.CreateTicketOutput\"@\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x1d\x8a\xe3\n\x19judge:contest:participate\x82\xd3\xe4\x93\x02\n\"\x08/tickets\x12\x99\x01\n\x0cUpdateTicket\x12\x1f.eolymp.judge.UpdateTicketInput\x1a .eolymp.judge.UpdateTicketOutput\"F\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02\x16\"\x14/tickets/{ticket_id}\x12\x97\x01\n\nReadTicket\x12\x1d.eolymp.judge.ReadTicketInput\x1a\x1e.eolymp.judge.ReadTicketOutput\"J\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02\x1b\"\x19/tickets/{ticket_id}/read\x12\x99\x01\n\x0c\x44\x65leteTicket\x12\x1f.eolymp.judge.DeleteTicketInput\x1a .eolymp.judge.DeleteTicketOutput\"F\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02\x16*\x14/tickets/{ticket_id}\x12\x9e\x01\n\x0e\x44\x65scribeTicket\x12!.eolymp.judge.DescribeTicketInput\x1a\".eolymp.judge.DescribeTicketOutput\"E\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02\x16\x12\x14/tickets/{ticket_id}\x12\x89\x01\n\x0bListTickets\x12\x1e.eolymp.judge.ListTicketsInput\x1a\x1f.eolymp.judge.ListTicketsOutput\"9\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02\n\x12\x08/tickets\x12\xa4\x01\n\x0bReplyTicket\x12\x1e.eolymp.judge.ReplyTicketInput\x1a\x1f.eolymp.judge.ReplyTicketOutput\"T\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xe3\n\x1d\x8a\xe3\n\x19judge:contest:participate\x82\xd3\xe4\x93\x02\x1e\"\x1c/tickets/{ticket_id}/replies\x12l\n\x0bWatchTicket\x12\x1e.eolymp.judge.WatchTicketInput\x1a\x1f.eolymp.judge.WatchTicketOutput\"\x1a\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read0\x01\x12o\n\x0cWatchTickets\x12\x1f.eolymp.judge.WatchTicketsInput\x1a .eolymp.judge.WatchTicketsOutput\"\x1a\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read0\x01\x12\x81\x01\n\x12WatchTicketSummary\x12%.eolymp.judge.WatchTicketSummaryInput\x1a&.eolymp.judge.WatchTicketSummaryOutput\"\x1a\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read0\x01\x12\x9d\x01\n\x0bListReplies\x12\x1e.eolymp.judge.ListRepliesInput\x1a\x1f.eolymp.judge.ListRepliesOutput\"M\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02\x1e\x12\x1c/tickets/{ticket_id}/replies\x12\xaf\x01\n\rDescribeReply\x12 .eolymp.judge.DescribeReplyInput\x1a!.eolymp.judge.DescribeReplyOutput\"Y\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02)\x12\'/tickets/{ticket_id}/replies/{reply_id}\x12\xa9\x01\n\x0b\x44\x65leteReply\x12\x1e.eolymp.judge.DeleteReplyInput\x1a\x1f.eolymp.judge.DeleteReplyOutput\"Y\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02)*\'/tickets/{ticket_id}/replies/{reply_id}\x12\xa9\x01\n\x0bUpdateReply\x12\x1e.eolymp.judge.UpdateReplyInput\x1a\x1f.eolymp.judge.UpdateReplyOutput\"Y\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02)\"\'/tickets/{ticket_id}/replies/{reply_id}\x12o\n\x0cWatchReplies\x12\x1f.eolymp.judge.WatchRepliesInput\x1a .eolymp.judge.WatchRepliesOutput\"\x1a\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read0\x01\x42-Z+github.com/eolymp/go-sdk/eolymp/judge;judgeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.judge.ticket_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/judge;judge'
  _globals['_TICKETSERVICE'].methods_by_name['CreateTicket']._loaded_options = None
  _globals['_TICKETSERVICE'].methods_by_name['CreateTicket']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\035\212\343\n\031judge:contest:participate\202\323\344\223\002\n\"\010/tickets'
  _globals['_TICKETSERVICE'].methods_by_name['UpdateTicket']._loaded_options = None
  _globals['_TICKETSERVICE'].methods_by_name['UpdateTicket']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002\026\"\024/tickets/{ticket_id}'
  _globals['_TICKETSERVICE'].methods_by_name['ReadTicket']._loaded_options = None
  _globals['_TICKETSERVICE'].methods_by_name['ReadTicket']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002\033\"\031/tickets/{ticket_id}/read'
  _globals['_TICKETSERVICE'].methods_by_name['DeleteTicket']._loaded_options = None
  _globals['_TICKETSERVICE'].methods_by_name['DeleteTicket']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002\026*\024/tickets/{ticket_id}'
  _globals['_TICKETSERVICE'].methods_by_name['DescribeTicket']._loaded_options = None
  _globals['_TICKETSERVICE'].methods_by_name['DescribeTicket']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002\026\022\024/tickets/{ticket_id}'
  _globals['_TICKETSERVICE'].methods_by_name['ListTickets']._loaded_options = None
  _globals['_TICKETSERVICE'].methods_by_name['ListTickets']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002\n\022\010/tickets'
  _globals['_TICKETSERVICE'].methods_by_name['ReplyTicket']._loaded_options = None
  _globals['_TICKETSERVICE'].methods_by_name['ReplyTicket']._serialized_options = b'\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\343\n\035\212\343\n\031judge:contest:participate\202\323\344\223\002\036\"\034/tickets/{ticket_id}/replies'
  _globals['_TICKETSERVICE'].methods_by_name['WatchTicket']._loaded_options = None
  _globals['_TICKETSERVICE'].methods_by_name['WatchTicket']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read'
  _globals['_TICKETSERVICE'].methods_by_name['WatchTickets']._loaded_options = None
  _globals['_TICKETSERVICE'].methods_by_name['WatchTickets']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read'
  _globals['_TICKETSERVICE'].methods_by_name['WatchTicketSummary']._loaded_options = None
  _globals['_TICKETSERVICE'].methods_by_name['WatchTicketSummary']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read'
  _globals['_TICKETSERVICE'].methods_by_name['ListReplies']._loaded_options = None
  _globals['_TICKETSERVICE'].methods_by_name['ListReplies']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002\036\022\034/tickets/{ticket_id}/replies'
  _globals['_TICKETSERVICE'].methods_by_name['DescribeReply']._loaded_options = None
  _globals['_TICKETSERVICE'].methods_by_name['DescribeReply']._serialized_options = b'\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002)\022\'/tickets/{ticket_id}/replies/{reply_id}'
  _globals['_TICKETSERVICE'].methods_by_name['DeleteReply']._loaded_options = None
  _globals['_TICKETSERVICE'].methods_by_name['DeleteReply']._serialized_options = b'\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002)*\'/tickets/{ticket_id}/replies/{reply_id}'
  _globals['_TICKETSERVICE'].methods_by_name['UpdateReply']._loaded_options = None
  _globals['_TICKETSERVICE'].methods_by_name['UpdateReply']._serialized_options = b'\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002)\"\'/tickets/{ticket_id}/replies/{reply_id}'
  _globals['_TICKETSERVICE'].methods_by_name['WatchReplies']._loaded_options = None
  _globals['_TICKETSERVICE'].methods_by_name['WatchReplies']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read'
  _globals['_TICKETCHANGEDEVENT']._serialized_start=338
  _globals['_TICKETCHANGEDEVENT']._serialized_end=448
  _globals['_REPLYCHANGEDEVENT']._serialized_start=450
  _globals['_REPLYCHANGEDEVENT']._serialized_end=561
  _globals['_CREATETICKETINPUT']._serialized_start=563
  _globals['_CREATETICKETINPUT']._serialized_end=678
  _globals['_CREATETICKETOUTPUT']._serialized_start=680
  _globals['_CREATETICKETOUTPUT']._serialized_end=719
  _globals['_UPDATETICKETINPUT']._serialized_start=722
  _globals['_UPDATETICKETINPUT']._serialized_end=895
  _globals['_UPDATETICKETINPUT_PATCH']._serialized_start=854
  _globals['_UPDATETICKETINPUT_PATCH']._serialized_end=895
  _globals['_UPDATETICKETOUTPUT']._serialized_start=897
  _globals['_UPDATETICKETOUTPUT']._serialized_end=917
  _globals['_READTICKETINPUT']._serialized_start=919
  _globals['_READTICKETINPUT']._serialized_end=1022
  _globals['_READTICKETOUTPUT']._serialized_start=1024
  _globals['_READTICKETOUTPUT']._serialized_end=1042
  _globals['_DELETETICKETINPUT']._serialized_start=1044
  _globals['_DELETETICKETINPUT']._serialized_end=1102
  _globals['_DELETETICKETOUTPUT']._serialized_start=1104
  _globals['_DELETETICKETOUTPUT']._serialized_end=1124
  _globals['_DESCRIBETICKETINPUT']._serialized_start=1126
  _globals['_DESCRIBETICKETINPUT']._serialized_end=1230
  _globals['_DESCRIBETICKETOUTPUT']._serialized_start=1232
  _globals['_DESCRIBETICKETOUTPUT']._serialized_end=1292
  _globals['_LISTTICKETSINPUT']._serialized_start=1295
  _globals['_LISTTICKETSINPUT']._serialized_end=2006
  _globals['_LISTTICKETSINPUT_FILTER']._serialized_start=1556
  _globals['_LISTTICKETSINPUT_FILTER']._serialized_end=1966
  _globals['_LISTTICKETSINPUT_SORT']._serialized_start=1968
  _globals['_LISTTICKETSINPUT_SORT']._serialized_end=2006
  _globals['_LISTTICKETSOUTPUT']._serialized_start=2008
  _globals['_LISTTICKETSOUTPUT']._serialized_end=2105
  _globals['_REPLYTICKETINPUT']._serialized_start=2108
  _globals['_REPLYTICKETINPUT']._serialized_end=2238
  _globals['_REPLYTICKETOUTPUT']._serialized_start=2240
  _globals['_REPLYTICKETOUTPUT']._serialized_end=2277
  _globals['_WATCHTICKETINPUT']._serialized_start=2279
  _globals['_WATCHTICKETINPUT']._serialized_end=2360
  _globals['_WATCHTICKETOUTPUT']._serialized_start=2362
  _globals['_WATCHTICKETOUTPUT']._serialized_end=2419
  _globals['_WATCHTICKETSINPUT']._serialized_start=2421
  _globals['_WATCHTICKETSINPUT']._serialized_end=2539
  _globals['_WATCHTICKETSOUTPUT']._serialized_start=2542
  _globals['_WATCHTICKETSOUTPUT']._serialized_end=2722
  _globals['_WATCHTICKETSOUTPUT_EVENT']._serialized_start=2657
  _globals['_WATCHTICKETSOUTPUT_EVENT']._serialized_end=2722
  _globals['_WATCHTICKETSUMMARYINPUT']._serialized_start=2724
  _globals['_WATCHTICKETSUMMARYINPUT']._serialized_end=2788
  _globals['_WATCHTICKETSUMMARYOUTPUT']._serialized_start=2790
  _globals['_WATCHTICKETSUMMARYOUTPUT']._serialized_end=2864
  _globals['_LISTREPLIESINPUT']._serialized_start=2866
  _globals['_LISTREPLIESINPUT']._serialized_end=2976
  _globals['_LISTREPLIESOUTPUT']._serialized_start=2978
  _globals['_LISTREPLIESOUTPUT']._serialized_end=3048
  _globals['_DESCRIBEREPLYINPUT']._serialized_start=3050
  _globals['_DESCRIBEREPLYINPUT']._serialized_end=3150
  _globals['_DESCRIBEREPLYOUTPUT']._serialized_start=3152
  _globals['_DESCRIBEREPLYOUTPUT']._serialized_end=3209
  _globals['_DELETEREPLYINPUT']._serialized_start=3211
  _globals['_DELETEREPLYINPUT']._serialized_end=3266
  _globals['_DELETEREPLYOUTPUT']._serialized_start=3268
  _globals['_DELETEREPLYOUTPUT']._serialized_end=3287
  _globals['_UPDATEREPLYINPUT']._serialized_start=3289
  _globals['_UPDATEREPLYINPUT']._serialized_end=3382
  _globals['_UPDATEREPLYOUTPUT']._serialized_start=3384
  _globals['_UPDATEREPLYOUTPUT']._serialized_end=3403
  _globals['_WATCHREPLIESINPUT']._serialized_start=3405
  _globals['_WATCHREPLIESINPUT']._serialized_end=3502
  _globals['_WATCHREPLIESOUTPUT']._serialized_start=3505
  _globals['_WATCHREPLIESOUTPUT']._serialized_end=3683
  _globals['_WATCHREPLIESOUTPUT_EVENT']._serialized_start=2657
  _globals['_WATCHREPLIESOUTPUT_EVENT']._serialized_end=2722
  _globals['_TICKETSERVICE']._serialized_start=3686
  _globals['_TICKETSERVICE']._serialized_end=5935
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/helpdesk/ticket.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/helpdesk/ticket.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.ecm import content_pb2 as eolymp_dot_ecm_dot_content__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x65olymp/helpdesk/ticket.proto\x12\x0f\x65olymp.helpdesk\x1a\x18\x65olymp/ecm/content.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb5\x07\n\x06Ticket\x12\n\n\x02id\x18\x01 \x01(\t\x12*\n\x04type\x18\x02 \x01(\x0e\x32\x1c.eolymp.helpdesk.Ticket.Type\x12\x0f\n\x07user_id\x18\x03 \x01(\t\x12\x12\n\nuser_email\x18\x04 \x01(\t\x12\x37\n\x08metadata\x18\x05 \x03(\x0b\x32%.eolymp.helpdesk.Ticket.MetadataEntry\x12.\n\x06status\x18\x06 \x01(\x0e\x32\x1e.eolymp.helpdesk.Ticket.Status\x12\x0e\n\x06locale\x18\t \x01(\t\x12.\n\ncreated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06secret\x18\x0c \x01(\t\x12\x0f\n\x07subject\x18\x14 \x01(\t\x12$\n\x07message\x18\x32 \x01(\x0b\x32\x13.eolymp.ecm.Content\x1a\xb2\x02\n\x07\x43omment\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x03 \x01(\t\x12\x12\n\nuser_email\x18\x04 \x01(\t\x12?\n\x08metadata\x18\x05 \x03(\x0b\x32-.eolymp.helpdesk.Ticket.Comment.MetadataEntry\x12.\n\ncreated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12$\n\x07message\x18\x32 \x01(\x0b\x32\x13.eolymp.ecm.Content\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"n\n\x04Type\x12\x08\n\x04NONE\x10\x00\x12\x0c\n\x08QUESTION\x10\x01\x12\x12\n\x0eQUOTA_INCREASE\x10\x02\x12\x0c\n\x08\x46\x45\x45\x44\x42\x41\x43K\x10\x03\x12\x19\n\x15\x41\x43\x41\x44\x45MIC_PLAN_REQUEST\x10\x04\x12\x11\n\rSALES_REQUEST\x10\x05\"X\n\x06Status\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\x0c\n\x08\x41WAITING\x10\x02\x12\n\n\x06\x43LOSED\x10\x03\x12\x0c\n\x08\x41PPROVED\x10\x04\x12\x0c\n\x08REJECTED\x10\x05\x42\x33Z1github.com/eolymp/go-sdk/eolymp/helpdesk;helpdeskb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.helpdesk.ticket_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/helpdesk;helpdesk'
  _globals['_TICKET_COMMENT_METADATAENTRY']._loaded_options = None
  _globals['_TICKET_COMMENT_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_TICKET_METADATAENTRY']._loaded_options = None
  _globals['_TICKET_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_TICKET']._serialized_start=109
  _globals['_TICKET']._serialized_end=1058
  _globals['_TICKET_COMMENT']._serialized_start=501
  _globals['_TICKET_COMMENT']._serialized_end=807
  _globals['_TICKET_COMMENT_METADATAENTRY']._serialized_start=760
  _globals['_TICKET_COMMENT_METADATAENTRY']._serialized_end=807
  _globals['_TICKET_METADATAENTRY']._serialized_start=760
  _globals['_TICKET_METADATAENTRY']._serialized_end=807
  _globals['_TICKET_TYPE']._serialized_start=858
  _globals['_TICKET_TYPE']._serialized_end=968
  _globals['_TICKET_STATUS']._serialized_start=970
  _globals['_TICKET_STATUS']._serialized_end=1058
# @@protoc_insertion_point(module_scope)



from eolymp.ecm import content_pb2 as _content_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Editorial(_message.Message):
    __slots__ = ("id", "locale", "automatic", "draft", "content", "download_link", "author_id")
    class Extra(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        NO_EXTRA: _ClassVar[Editorial.Extra]
        CONTENT_RENDER: _ClassVar[Editorial.Extra]
        CONTENT_VALUE: _ClassVar[Editorial.Extra]
    NO_EXTRA: Editorial.Extra
    CONTENT_RENDER: Editorial.Extra
    CONTENT_VALUE: Editorial.Extra
    class Patch(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_PATCH: _ClassVar[Editorial.Patch]
        PATCH_ALL: _ClassVar[Editorial.Patch]
        PATCH_LOCALE: _ClassVar[Editorial.Patch]
        PATCH_AUTOMATIC: _ClassVar[Editorial.Patch]
        PATCH_DRAFT: _ClassVar[Editorial.Patch]
        PATCH_CONTENT: _ClassVar[Editorial.Patch]
        PATCH_DOWNLOAD_LINK: _ClassVar[Editorial.Patch]
        PATCH_AUTHOR_ID: _ClassVar[Editorial.Patch]
    UNKNOWN_PATCH: Editorial.Patch
    PATCH_ALL: Editorial.Patch
    PATCH_LOCALE: Editorial.Patch
    PATCH_AUTOMATIC: Editorial.Patch
    PATCH_DRAFT: Editorial.Patch
    PATCH_CONTENT: Editorial.Patch
    PATCH_DOWNLOAD_LINK: Editorial.Patch
    PATCH_AUTHOR_ID: Editorial.Patch
    ID_FIELD_NUMBER: _ClassVar[int]
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    AUTOMATIC_FIELD_NUMBER: _ClassVar[int]
    DRAFT_FIELD_NUMBER: _ClassVar[int]
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    DOWNLOAD_LINK_FIELD_NUMBER: _ClassVar[int]
    AUTHOR_ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    locale: str
    automatic: bool
    draft: bool
    content: _content_pb2.Content
    download_link: str
    author_id: str
    def __init__(self, id: _Optional[str] = ..., locale: _Optional[str] = ..., automatic: bool = ..., draft: bool = ..., content: _Optional[_Union[_content_pb2.Content, _Mapping]] = ..., download_link: _Optional[str] = ..., author_id: _Optional[str] = ...) -> None: ...



from eolymp.wellknown import link_pb2 as _link_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Entry(_message.Message):
    __slots__ = ("id", "type", "timestamp", "attributes", "links")
    class AttributesEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    ATTRIBUTES_FIELD_NUMBER: _ClassVar[int]
    LINKS_FIELD_NUMBER: _ClassVar[int]
    id: str
    type: str
    timestamp: _timestamp_pb2.Timestamp
    attributes: _containers.ScalarMap[str, str]
    links: _containers.RepeatedCompositeFieldContainer[_link_pb2.Link]
    def __init__(self, id: _Optional[str] = ..., type: _Optional[str] = ..., timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., attributes: _Optional[_Mapping[str, str]] = ..., links: _Optional[_Iterable[_Union[_link_pb2.Link, _Mapping]]] = ...) -> None: ...



from google.protobuf import descriptor_pb2 as _descriptor_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor
ENDPOINT_FIELD_NUMBER: _ClassVar[int]
endpoint: _descriptor.FieldDescriptor

class Endpoint(_message.Message):
    __slots__ = ("field", "service")
    class Service(_message.Message):
        __slots__ = ("name",)
        NAME_FIELD_NUMBER: _ClassVar[int]
        name: str
        def __init__(self, name: _Optional[str] = ...) -> None: ...
    FIELD_FIELD_NUMBER: _ClassVar[int]
    SERVICE_FIELD_NUMBER: _ClassVar[int]
    field: str
    service: _containers.RepeatedCompositeFieldContainer[Endpoint.Service]
    def __init__(self, field: _Optional[str] = ..., service: _Optional[_Iterable[_Union[Endpoint.Service, _Mapping]]] = ...) -> None: ...



from eolymp.webhook import webhook_pb2 as _webhook_pb2
from google.protobuf import any_pb2 as _any_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Delivery(_message.Message):
    __slots__ = ("id", "webhook_id", "timestamp", "event", "payload")
    ID_FIELD_NUMBER: _ClassVar[int]
    WEBHOOK_ID_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    EVENT_FIELD_NUMBER: _ClassVar[int]
    PAYLOAD_FIELD_NUMBER: _ClassVar[int]
    id: str
    webhook_id: str
    timestamp: _timestamp_pb2.Timestamp
    event: _webhook_pb2.Webhook.Event
    payload: _any_pb2.Any
    def __init__(self, id: _Optional[str] = ..., webhook_id: _Optional[str] = ..., timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., event: _Optional[_Union[_webhook_pb2.Webhook.Event, str]] = ..., payload: _Optional[_Union[_any_pb2.Any, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler. DO NOT EDIT!
# See https://github.com/eolymp/contracts/tree/main/cmd/protoc-gen-python-esdk for more details.
"""Generated protocol buffer code."""

import urllib.parse
from google.protobuf import symbol_database as _symbol_database

_sym_db = _symbol_database.Default()


class ParticipantServiceClient:
    def __init__(self, transport, url="https://api.eolymp.com"):
        self.transport = transport
        self.url = url

    def AssignParticipant(self, request, **kwargs):
        path = "/participants"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.AssignParticipantOutput"),
            **kwargs,
        )

    def EnableParticipant(self, request, **kwargs):
        path = "/participants/"+urllib.parse.quote(request.participant_id)+"/enable"

        # Cleanup URL parameters to avoid any ambiguity
        request.participant_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.EnableParticipantOutput"),
            **kwargs,
        )

    def DisableParticipant(self, request, **kwargs):
        path = "/participants/"+urllib.parse.quote(request.participant_id)+"/disable"

        # Cleanup URL parameters to avoid any ambiguity
        request.participant_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.DisableParticipantOutput"),
            **kwargs,
        )

    def UpdateParticipant(self, request, **kwargs):
        path = "/participants/"+urllib.parse.quote(request.participant_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.participant_id = ""

        return self.transport.request(
            method="PUT",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.UpdateParticipantOutput"),
            **kwargs,
        )

    def DisqualifyParticipant(self, request, **kwargs):
        path = "/participants/"+urllib.parse.quote(request.participant_id)+"/disqualify"

        # Cleanup URL parameters to avoid any ambiguity
        request.participant_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.DisqualifyParticipantOutput"),
            **kwargs,
        )

    def DeleteParticipant(self, request, **kwargs):
        path = "/participants/"+urllib.parse.quote(request.participant_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.participant_id = ""

        return self.transport.request(
            method="DELETE",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.DeleteParticipantOutput"),
            **kwargs,
        )

    def DescribeParticipant(self, request, **kwargs):
        path = "/participants/"+urllib.parse.quote(request.participant_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.participant_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.DescribeParticipantOutput"),
            **kwargs,
        )

    def ListParticipants(self, request, **kwargs):
        path = "/participants"

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.ListParticipantsOutput"),
            **kwargs,
        )

    def DescribeViewer(self, request, **kwargs):
        path = "/introspect"

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.DescribeViewerOutput"),
            **kwargs,
        )

    def JoinContest(self, request, **kwargs):
        path = "/join"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.JoinContestOutput"),
            **kwargs,
        )

    def StartContest(self, request, **kwargs):
        path = "/start"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.StartContestOutput"),
            **kwargs,
        )




# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/judge/passcode_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/judge/passcode_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#eolymp/judge/passcode_service.proto\x12\x0c\x65olymp.judge\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\")\n\x13VerifyPasscodeInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"7\n\x14VerifyPasscodeOutput\x12\x10\n\x08required\x18\x01 \x01(\x08\x12\r\n\x05valid\x18\x02 \x01(\x08\":\n\x12\x45nterPasscodeInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x10\n\x08passcode\x18\x02 \x01(\t\"\x15\n\x13\x45nterPasscodeOutput\"@\n\x12ResetPasscodeInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x16\n\x0eparticipant_id\x18\x02 \x01(\t\"\'\n\x13ResetPasscodeOutput\x12\x10\n\x08passcode\x18\x01 \x01(\t\"P\n\x10SetPasscodeInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x16\n\x0eparticipant_id\x18\x02 \x01(\t\x12\x10\n\x08passcode\x18\x03 \x01(\t\"\x13\n\x11SetPasscodeOutput\"A\n\x13RemovePasscodeInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x16\n\x0eparticipant_id\x18\x02 \x01(\t\"\x16\n\x14RemovePasscodeOutput2\xe1\x06\n\x0fPasscodeService\x12\x9a\x01\n\x0eVerifyPasscode\x12!.eolymp.judge.VerifyPasscodeInput\x1a\".eolymp.judge.VerifyPasscodeOutput\"A\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02\x12\"\x10/verify-passcode\x12\x9d\x01\n\rEnterPasscode\x12 .eolymp.judge.EnterPasscodeInput\x1a!.eolymp.judge.EnterPasscodeOutput\"G\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xe3\n\x1d\x8a\xe3\n\x19judge:contest:participate\x82\xd3\xe4\x93\x02\x11\"\x0f/enter-passcode\x12\xaf\x01\n\rResetPasscode\x12 .eolymp.judge.ResetPasscodeInput\x1a!.eolymp.judge.ResetPasscodeOutput\"Y\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02)\"\'/participants/{participant_id}/passcode\x12\xa9\x01\n\x0bSetPasscode\x12\x1e.eolymp.judge.SetPasscodeInput\x1a\x1f.eolymp.judge.SetPasscodeOutput\"Y\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02)\x1a\'/participants/{participant_id}/passcode\x12\xb2\x01\n\x0eRemovePasscode\x12!.eolymp.judge.RemovePasscodeInput\x1a\".eolymp.judge.RemovePasscodeOutput\"Y\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02)*\'/participants/{participant_id}/passcodeB-Z+github.com/eolymp/go-sdk/eolymp/judge;judgeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.judge.passcode_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/judge;judge'
  _globals['_PASSCODESERVICE'].methods_by_name['VerifyPasscode']._loaded_options = None
  _globals['_PASSCODESERVICE'].methods_by_name['VerifyPasscode']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002\022\"\020/verify-passcode'
  _globals['_PASSCODESERVICE'].methods_by_name['EnterPasscode']._loaded_options = None
  _globals['_PASSCODESERVICE'].methods_by_name['EnterPasscode']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\343\n\035\212\343\n\031judge:contest:participate\202\323\344\223\002\021\"\017/enter-passcode'
  _globals['_PASSCODESERVICE'].methods_by_name['ResetPasscode']._loaded_options = None
  _globals['_PASSCODESERVICE'].methods_by_name['ResetPasscode']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002)\"\'/participants/{participant_id}/passcode'
  _globals['_PASSCODESERVICE'].methods_by_name['SetPasscode']._loaded_options = None
  _globals['_PASSCODESERVICE'].methods_by_name['SetPasscode']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002)\032\'/participants/{participant_id}/passcode'
  _globals['_PASSCODESERVICE'].methods_by_name['RemovePasscode']._loaded_options = None
  _globals['_PASSCODESERVICE'].methods_by_name['RemovePasscode']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002)*\'/participants/{participant_id}/passcode'
  _globals['_VERIFYPASSCODEINPUT']._serialized_start=152
  _globals['_VERIFYPASSCODEINPUT']._serialized_end=193
  _globals['_VERIFYPASSCODEOUTPUT']._serialized_start=195
  _globals['_VERIFYPASSCODEOUTPUT']._serialized_end=250
  _globals['_ENTERPASSCODEINPUT']._serialized_start=252
  _globals['_ENTERPASSCODEINPUT']._serialized_end=310
  _globals['_ENTERPASSCODEOUTPUT']._serialized_start=312
  _globals['_ENTERPASSCODEOUTPUT']._serialized_end=333
  _globals['_RESETPASSCODEINPUT']._serialized_start=335
  _globals['_RESETPASSCODEINPUT']._serialized_end=399
  _globals['_RESETPASSCODEOUTPUT']._serialized_start=401
  _globals['_RESETPASSCODEOUTPUT']._serialized_end=440
  _globals['_SETPASSCODEINPUT']._serialized_start=442
  _globals['_SETPASSCODEINPUT']._serialized_end=522
  _globals['_SETPASSCODEOUTPUT']._serialized_start=524
  _globals['_SETPASSCODEOUTPUT']._serialized_end=543
  _globals['_REMOVEPASSCODEINPUT']._serialized_start=545
  _globals['_REMOVEPASSCODEINPUT']._serialized_end=610
  _globals['_REMOVEPASSCODEOUTPUT']._serialized_start=612
  _globals['_REMOVEPASSCODEOUTPUT']._serialized_end=634
  _globals['_PASSCODESERVICE']._serialized_start=637
  _globals['_PASSCODESERVICE']._serialized_end=1502
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/wellknown/direction.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/wellknown/direction.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n eolymp/wellknown/direction.proto\x12\x10\x65olymp.wellknown*\x1e\n\tDirection\x12\x07\n\x03\x41SC\x10\x00\x12\x08\n\x04\x44\x45SC\x10\x01\x42\x35Z3github.com/eolymp/go-sdk/eolymp/wellknown;wellknownb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.wellknown.direction_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/wellknown;wellknown'
  _globals['_DIRECTION']._serialized_start=54
  _globals['_DIRECTION']._serialized_end=84
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/playground/playground.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/playground/playground.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.playground import run_pb2 as eolymp_dot_playground_dot_run__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"eolymp/playground/playground.proto\x12\x11\x65olymp.playground\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1b\x65olymp/playground/run.proto\"e\n\x0e\x43reateRunInput\x12\x0f\n\x07runtime\x18\x02 \x01(\t\x12\x0e\n\x06source\x18\x64 \x01(\t\x12\x14\n\ninput_data\x18\x65 \x01(\x0cH\x00\x12\x13\n\tinput_ref\x18\x66 \x01(\tH\x00\x42\x07\n\x05input\"!\n\x0f\x43reateRunOutput\x12\x0e\n\x06run_id\x18\x01 \x01(\t\"\"\n\x10\x44\x65scribeRunInput\x12\x0e\n\x06run_id\x18\x01 \x01(\t\"8\n\x11\x44\x65scribeRunOutput\x12#\n\x03run\x18\x01 \x01(\x0b\x32\x16.eolymp.playground.Run\"\x1f\n\rWatchRunInput\x12\x0e\n\x06run_id\x18\x01 \x01(\t\"5\n\x0eWatchRunOutput\x12#\n\x03run\x18\x01 \x01(\x0b\x32\x16.eolymp.playground.Run2\xd4\x03\n\nPlayground\x12\x8c\x01\n\tCreateRun\x12!.eolymp.playground.CreateRunInput\x1a\".eolymp.playground.CreateRunOutput\"8\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xe3\n\x18\x8a\xe3\n\x14playground:run:write\x82\xd3\xe4\x93\x02\x07\"\x05/runs\x12\x9a\x01\n\x0b\x44\x65scribeRun\x12#.eolymp.playground.DescribeRunInput\x1a$.eolymp.playground.DescribeRunOutput\"@\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x17\x8a\xe3\n\x13playground:run:read\x82\xd3\xe4\x93\x02\x10\x12\x0e/runs/{run_id}\x12\x99\x01\n\x08WatchRun\x12 .eolymp.playground.WatchRunInput\x1a!.eolymp.playground.WatchRunOutput\"F\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x17\x8a\xe3\n\x13playground:run:read\x82\xd3\xe4\x93\x02\x16\x12\x14/runs/{run_id}/watch0\x01\x42\x37Z5github.com/eolymp/go-sdk/eolymp/playground;playgroundb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.playground.playground_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z5github.com/eolymp/go-sdk/eolymp/playground;playground'
  _globals['_PLAYGROUND'].methods_by_name['CreateRun']._loaded_options = None
  _globals['_PLAYGROUND'].methods_by_name['CreateRun']._serialized_options = b'\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\343\n\030\212\343\n\024playground:run:write\202\323\344\223\002\007\"\005/runs'
  _globals['_PLAYGROUND'].methods_by_name['DescribeRun']._loaded_options = None
  _globals['_PLAYGROUND'].methods_by_name['DescribeRun']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\027\212\343\n\023playground:run:read\202\323\344\223\002\020\022\016/runs/{run_id}'
  _globals['_PLAYGROUND'].methods_by_name['WatchRun']._loaded_options = None
  _globals['_PLAYGROUND'].methods_by_name['WatchRun']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\027\212\343\n\023playground:run:read\202\323\344\223\002\026\022\024/runs/{run_id}/watch'
  _globals['_CREATERUNINPUT']._serialized_start=185
  _globals['_CREATERUNINPUT']._serialized_end=286
  _globals['_CREATERUNOUTPUT']._serialized_start=288
  _globals['_CREATERUNOUTPUT']._serialized_end=321
  _globals['_DESCRIBERUNINPUT']._serialized_start=323
  _globals['_DESCRIBERUNINPUT']._serialized_end=357
  _globals['_DESCRIBERUNOUTPUT']._serialized_start=359
  _globals['_DESCRIBERUNOUTPUT']._serialized_end=415
  _globals['_WATCHRUNINPUT']._serialized_start=417
  _globals['_WATCHRUNINPUT']._serialized_end=448
  _globals['_WATCHRUNOUTPUT']._serialized_start=450
  _globals['_WATCHRUNOUTPUT']._serialized_end=503
  _globals['_PLAYGROUND']._serialized_start=506
  _globals['_PLAYGROUND']._serialized_end=974
# @@protoc_insertion_point(module_scope)
